[Zope3-checkins] CVS: Zope3/src/zope/index/interfaces - __init__.py:1.5

Andreas Jung andreas@andreas-jung.com
Thu, 17 Jul 2003 14:39:08 -0400


Update of /cvs-repository/Zope3/src/zope/index/interfaces
In directory cvs.zope.org:/tmp/cvs-serv6590/interfaces

Modified Files:
	__init__.py 
Log Message:
- added  ITopicQuerying
- test for reindexing
- cleanup


=== Zope3/src/zope/index/interfaces/__init__.py 1.4 => 1.5 ===
--- Zope3/src/zope/index/interfaces/__init__.py:1.4	Wed Jul 16 12:56:34 2003
+++ Zope3/src/zope/index/interfaces/__init__.py	Thu Jul 17 14:38:32 2003
@@ -131,6 +131,16 @@
            Return an IISet of docids
         """
 
+class ITopicQuerying(Interface):
+
+    def search(query, operator='and'):
+        """Execute a search given by 'query' as a list/tuple of filter ids.
+          'operator' can be 'and' or 'or' to search for matches in all
+           or any filter.
+
+           Return an IISet of docids
+        """
+
 class ISimpleQuery(Interface):
     "a simple query interface"
 
@@ -138,8 +148,8 @@
         "search for the given term, return a sequence of hubids"
 
 
-class ITopicFilter(Interface):
-    """ interface for filters used by topic indexes """
+class ITopicFilteredSet(Interface):
+    """ interface for filtered sets used by topic indexes """
     
     def clear():
         """clearn the index"""